from django_cloudspotlicense import PACKAGE_NAME

ROOT_PERM='use_app'
SUPERUSER_PERM='is_superuser'

def get_root_perm():
    return f'{PACKAGE_NAME}.{ROOT_PERM}'

def get_superuser_perm():
    return f'{PACKAGE_NAME}.{SUPERUSER_PERM}'


from django_cloudspotlicense import PACKAGE_NAME
from .config import get_superuser_perm

def has_perm(user, perm):
    """ Returns True if user has the specified permission on the Cloudspot License server. """
    
    if user.has_perm(get_superuser_perm()):
        return True
    else:
        license_perm = '{0}.{1}'.format(PACKAGE_NAME, perm)
        return user.has_perm(license_perm)


from django import template
from django_cloudspotlicense import PACKAGE_NAME
from django_cloudspotlicense.utils import has_perm as util_has_perm

register = template.Library()

@register.filter(name='has_perm')
def has_perm(user, perm):
    """ Returns True if user has the specified permission on the Cloudspot License server. """
    return util_has_perm(user, perm)